AccountInfo

Struct AccountInfo 

#[repr(C)]
pub struct AccountInfo<'a> { pub key: &'a Pubkey, pub lamports: Rc<RefCell<&'a mut u64>>, pub utxo: &'a UtxoMeta, pub data: Rc<RefCell<&'a mut [u8]>>, pub owner: &'a Pubkey, pub is_signer: bool, pub is_writable: bool, pub is_executable: bool, }
Account information that is passed to programs during instruction execution. The account’s data contains the actual account state managed by programs.

Fields

key: &'a Pubkeylamports: Rc<RefCell<&'a mut u64>>

The lamports in the account. Modifiable by programs.

utxo: &'a UtxoMetadata: Rc<RefCell<&'a mut [u8]>>owner: &'a Pubkeyis_signer: boolis_writable: boolis_executable: bool

Implementations

Source

impl<'a> AccountInfo<'a>

pub fn new( key: &'a Pubkey, lamports: &'a mut u64, data: &'a mut [u8], owner: &'a Pubkey, utxo: &'a UtxoMeta, is_signer: bool, is_writable: bool, is_executable: bool, ) -> Self

Creates a new AccountInfo instance.

Arguments
  • key - The account’s public key
  • data - The account’s mutable data
  • owner - The program that owns this account
  • utxo - The UTXO metadata associated with this account
  • is_signer - Whether this account is a signer
  • is_writable - Whether this account is writable
  • is_executable - Whether this account contains executable code
pub fn data_len(&self) -> usize

Returns the length of the account’s data.

Returns

The length of the account’s data in bytes

pub fn try_data_len(&self) -> Result<usize, ProgramError>

pub fn data_is_empty(&self) -> bool

pub fn try_data_is_empty(&self) -> Result<bool, ProgramError>

pub fn signer_key(&self) -> Option<&Pubkey>

pub fn unsigned_key(&self) -> &Pubkey

pub fn lamports(&self) -> u64

pub fn try_lamports(&self) -> Result<u64, ProgramError>

pub fn try_borrow_lamports(&self) -> Result<Ref<'_, &mut u64>, ProgramError>

pub fn try_borrow_mut_lamports( &self, ) -> Result<RefMut<'_, &'a mut u64>, ProgramError>

pub fn try_borrow_data(&self) -> Result<Ref<'_, &mut [u8]>, ProgramError>

Immutably borrows the account’s data.

Returns
  • Ok(Ref<&mut [u8]>) - A reference to the account’s data
  • Err(ProgramError) - If the data is already mutably borrowed
pub fn try_borrow_mut_data( &self, ) -> Result<RefMut<'_, &'a mut [u8]>, ProgramError>

Mutably borrows the account’s data.

Returns
  • Ok(RefMut<&mut [u8]>) - A mutable reference to the account’s data
  • Err(ProgramError) - If the data is already borrowed
pub unsafe fn original_data_len(&self) -> usize

Return the account’s original data length when it was serialized for the current program invocation.

Safety

This method assumes that the original data length was serialized as a u64 integer in the 1 bytes immediately succeeding is_executable.

pub fn realloc( &self, new_len: usize, zero_init: bool, ) -> Result<(), ProgramError>

Realloc the account’s data and optionally zero-initialize the new memory.

Note: Account data can be increased within a single call by up to solana_program::entrypoint::MAX_PERMITTED_DATA_INCREASE bytes.

Note: Memory used to grow is already zero-initialized upon program entrypoint and re-zeroing it wastes compute units. If within the same call a program reallocs from larger to smaller and back to larger again the new space could contain stale data. Pass true for zero_init in this case, otherwise compute units will be wasted re-zero-initializing.

Safety

This method makes assumptions about the layout and location of memory referenced by AccountInfo fields. It should only be called for instances of AccountInfo that were created by the runtime and received in the process_instruction entrypoint of a program.

pub fn assign(&self, owner: &Pubkey)

Sets a new owner for the account.

Arguments
  • owner - The public key of the new owner program
Safety

This method uses unsafe operations to modify a non-mutable reference. It should only be used in contexts where this operation is valid.

pub fn get_utxo(&self) -> &UtxoMeta