pub enum SystemInstruction {
CreateAccount {
lamports: u64,
space: u64,
owner: Pubkey,
},
CreateAccountWithAnchor {
lamports: u64,
space: u64,
owner: Pubkey,
txid: [u8; 32],
vout: u32,
},
Assign {
owner: Pubkey,
},
Anchor {
txid: [u8; 32],
vout: u32,
},
SignInput {
index: u32,
},
Transfer {
lamports: u64,
},
Allocate {
space: u64,
},
CreateAccountWithSeed {
base: Pubkey,
seed: String,
lamports: u64,
space: u64,
owner: Pubkey,
},
AllocateWithSeed {
base: Pubkey,
seed: String,
space: u64,
owner: Pubkey,
},
AssignWithSeed {
base: Pubkey,
seed: String,
owner: Pubkey,
},
TransferWithSeed {
lamports: u64,
from_seed: String,
from_owner: Pubkey,
},
}Variants
CreateAccount
Create a new account
Account references
[WRITE, SIGNER]Funding account[WRITE, SIGNER]New account
Fields
CreateAccountWithAnchor
Create a new account with an anchor
Account references
[WRITE, SIGNER]Funding account[WRITE, SIGNER]New account
Fields
Assign
Anchor
SignInput
Transfer
Allocate
Allocate space in a (possibly new) account without funding
Account references
[WRITE, SIGNER]New account
CreateAccountWithSeed
Create a new account at an address derived from a base pubkey and a seed
Account references
[WRITE, SIGNER]Funding account[WRITE]Created account[SIGNER](optional) Base account; the account matching the base Pubkey below must be provided as a signer, but may be the same as the funding account and provided as account 0
Fields
AllocateWithSeed
Allocate space for and assign an account at an address derived from a base public key and a seed
Account references
[WRITE]Allocated account[SIGNER]Base account
Fields
AssignWithSeed
Assign account to a program based on a seed
Account references
[WRITE]Assigned account[SIGNER]Base account
Fields
TransferWithSeed
Transfer lamports from a derived address
Account references
[WRITE]Funding account[SIGNER]Base for funding account[WRITE]Recipient account