#[repr(C)]pub struct AccountMeta {
pub pubkey: Pubkey,
pub is_signer: bool,
pub is_writable: bool,
}Expand description
Meta information about an account used to define its role in an instruction. This includes whether the account is a signer and if it’s writable.
Fields
pubkey: Pubkeyis_signer: boolis_writable: boolImplementations
Sourceimpl AccountMeta
impl AccountMeta
Sourcepub fn new(pubkey: Pubkey, is_signer: bool) -> Self
pub fn new(pubkey: Pubkey, is_signer: bool) -> Self
Creates a new AccountMeta with the given public key as a writable account.
Arguments
pubkey- The account’s public keyis_signer- Whether this account is a transaction signer
Sourcepub fn new_readonly(pubkey: Pubkey, is_signer: bool) -> Self
pub fn new_readonly(pubkey: Pubkey, is_signer: bool) -> Self
Creates a new read-only AccountMeta with the given public key.
Arguments
pubkey- The account’s public keyis_signer- Whether this account is a transaction signer
Sourcepub fn serialize(&self) -> [u8; 34]
pub fn serialize(&self) -> [u8; 34]
Serializes the AccountMeta into a fixed-size byte array.
Returns
A 34-byte array containing the serialized account metadata
Sourcepub fn from_slice(data: &[u8]) -> Result<Self, SerialisationErrors>
pub fn from_slice(data: &[u8]) -> Result<Self, SerialisationErrors>