Bitcoin transaction signing utilities Transaction to sign representation for serialization and deserialization.
This module provides the TransactionToSign struct which represents a transaction
along with the inputs that need to be signed.
Structs
- Transaction
ToSign - Represents a transaction that needs to be signed with associated inputs.